/*
 *  Copyright 2003-2014  Mikhail Kryshen <mikhail@kryshen.net>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.games1729.shariks;

import com.games1729.util.ResourceLoader;
import java.awt.*;
import java.io.*;

class Skin {
    private final Game game;

    private Image[] head = new Image[8];
    private Image tail = null;
    private Image crazy = null;
    private Image background = null;
    private Image foreground = null;

    Thread loadThread;

    Skin(Game game) {
	this.game = game;
    }

    void load(InputStream in) throws IOException, 
				     InterruptedException {	
	ResourceLoader rl = new ResourceLoader
	    (game.component, "Shariks Skin", in);
       	
	for (;;) {
	    int progress = rl.loadNext();
	    game.setStatus("Loading Skin (" + (progress * 100 / 255) + "%)...");
	    if (progress == 0xFF) return;

	    String name = rl.getResourceName();
	    switch (rl.getResourceType()) {		
	    case ResourceLoader.DATA_IMAGE:
		if ("sharik-tail".equals(name)) {
		    tail = rl.getImage();
		} else if ("sharik-crazy".equals(name)) {
		    crazy = rl.getImage();
		} else if ("background".equals(name)) {
		    background = rl.getImage();
		} else if ("foreground".equals(name)) {
		    foreground = rl.getImage();
		} else if (name.startsWith("sharik-head")) {
		    int index = Integer.parseInt(name.substring(11));
		    if (index < head.length) head[index] = rl.getImage();
		}
		break;
	    }
	}       
    }

    Image getCrazyImage()               { return crazy; }
    Image getTailImage()                { return tail; }
    Image getHeadImage(int orientation) { return head[orientation]; }
    Image getBackground()               { return background; } 
    Image getForeground()               { return foreground; } 
}
