/*
 *  Copyright 2003-2014  Mikhail Kryshen <mikhail@kryshen.net>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.games1729.shariks;

class TailSharik extends Sharik {
    final static float RADIUS = 7f;
    final static float ROPE_MAX_LENGTH = 100f;
    final static float ROPE_MIN_LENGTH = 10f;
    final static float ROPE_STRENGTH = 0.05f;
    final static float LINKS_MAX = 5;

    Sharik link = null;

    // used in Field.findWinner()
    boolean linked;

    TailSharik(Field field) {
	super(field);
	this.m = 1000f;
	this.r = RADIUS;
	this.drag = 7f;
	this.look = field.NOBODY.look;
    }

    Vector2D getAttractingForce(Sharik s) {
 	Vector2D f = super.getAttractingForce(s);

	if ((s == link || link == null) && 
	    !(s instanceof TailSharik && ((TailSharik)s).link == this)) {

	    float dx = x - s.x;
	    float dy = y - s.y;

	    if (dx * dx + dy * dy < ROPE_MAX_LENGTH * ROPE_MAX_LENGTH 
		&& Game.random.nextInt() % 10000 != 0) {

		float r = this.r + s.r + ROPE_MIN_LENGTH;
	    
		Vector2D d = new Vector2D(dx, dy);
		d.normalize();
		d.x *= r; d.y *= r;
		
		dx -= d.x;
		dy -= d.y;
		
		f.add(dx * ROPE_STRENGTH, dy * ROPE_STRENGTH);
		
		link = s;
		
		this.look = s.look;

	    } else {
		link = null;
	    }
	}

	return f;
    }
}
